==> TundereBird-0.23.tar.bz2: TundereBird-0.23/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4/ImapAppendedUidSet.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Imap4 {
  // RFC 4315 Internet Message Access Protocol (IMAP) - UIDPLUS extension
  // http://tools.ietf.org/html/rfc4315
  // APPENDUID response code
  public class ImapAppendedUidSet : ImapSequenceSet {
    /// <value>the UIDVALIDITY of the destination mailbox</value>
    public long UidValidity {
      get; private set;
    }

    /// <value>the UID assigned to the appended message in the destination mailbox</value>
    protected ImapSequenceSet AssignedUidSet {
      get { return assignedUidSet; }
    }

    public override bool IsUidSet {
      get { return true; }
    }

    public override bool IsEmpty {
      get { return assignedUidSet.IsEmpty; }
    }

    internal ImapAppendedUidSet(long uidValidity, ImapSequenceSet assignedUidSet)
      : base(true)
    {
      this.UidValidity = uidValidity;
      this.assignedUidSet = assignedUidSet;
    }

    public override long[] ToArray()
    {
      return assignedUidSet.ToArray();
    }

    public override string ToString()
    {
      return assignedUidSet.ToString();
    }

    private ImapSequenceSet assignedUidSet;
  }
}

==> TundereBird-0.24.tar.bz2: TundereBird-0.24/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4/ImapAppendedUidSet.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Net.Imap4 {
  // RFC 4315 Internet Message Access Protocol (IMAP) - UIDPLUS extension
  // http://tools.ietf.org/html/rfc4315
  // APPENDUID response code
  public class ImapAppendedUidSet : ImapSequenceSet {
    public override bool IsUidSet {
      get { return true; }
    }

    public override bool IsEmpty {
      get { return AssignedUidSet.IsEmpty; }
    }

    public override bool IsSingle {
      get { return AssignedUidSet.IsSingle; }
    }

    /// <value>the UIDVALIDITY of the destination mailbox</value>
    public long UidValidity {
      get; private set;
    }

    /// <value>the UID assigned to the appended message in the destination mailbox</value>
    public ImapSequenceSet AssignedUidSet {
      get; private set;
    }

    internal ImapAppendedUidSet(long uidValidity, ImapSequenceSet assignedUidSet)
      : base(true)
    {
      this.UidValidity = uidValidity;
      this.AssignedUidSet = assignedUidSet;
    }

    public override long ToNumber()
    {
      return AssignedUidSet.ToNumber();
    }

    public override long[] ToArray()
    {
      return AssignedUidSet.ToArray();
    }

    public override string ToString()
    {
      return AssignedUidSet.ToString();
    }
  }
}
